#include "testlib.h"
#include <iostream>

using namespace std;

typedef long long ll;
#define x first
#define y second
ll sqr(ll x) { return x*x; }

const ll MAX_SIZE = (ll)1e6, N_SIZE = 100;

pair <ll, ll> get_sqrt(ll x) {
    if (x == 0) return {0, 1};
    
	ll a = 1, b = x;
	for (ll i = sqrt(x) + 1; i >= 2; --i) {
		if (b % sqr(i) == 0) {
			b /= sqr(i);
			a *= i;
		}
	}

	return {a, b};
}

int main(int argc, char * argv[]) {
    setName("Checks the route for correctness.");
    registerTestlibCmd(argc, argv);

    int q = inf.readInt();
    int p = inf.readInt();

    int n = ouf.readInt(2, N_SIZE, "n");

    vector <pair <ll, ll> > points(n);
    points[0].x = ouf.readInt(0, 0, "point_0.x");
    points[0].y = ouf.readInt(0, 0, "point_0.y");

    for (int i = 1; i < n; ++i) {
    	points[i].x = ouf.readInt(0, MAX_SIZE, "point.x");
    	points[i].y = ouf.readInt(0, MAX_SIZE, "point.y");
    	
    	if (points[i] == points[i - 1]) {
    	    quitf(_wa, "Incorrect output, two identical points were entered.");
    	}
    }

    ll dist_sqr = sqr(points[n - 1].x) + sqr(points[n - 1].y);
    pair <ll, ll> dist = get_sqrt(dist_sqr);
    ll way = 0;

    for (int i = 1; i < n; ++i) {
    	pair <ll, ll> cur = get_sqrt(sqr(points[i].x - points[i - 1].x) + sqr(points[i].y - points[i - 1].y));
    	if (cur.y != dist.y) {
    		quitf(_wa, "The ratio of numbers is irrational.");
    	} else {
    		way += cur.x;
    	}
    }

    if (way * q != dist.x * p) {
		quitf(_wa, "The ratio of the path and the distance is not equal to the p/q, path = %lld, dist = %lld", way,  dist);
    }

    quitf(_ok, "OK");

    return 0;
}